module top_mdyCfgDds(
           clk       ,
           rst_n     ,
           rx        ,
           tx        ,
           dac_mode  ,
           dac_clka  ,
           dac_da    ,
           dac_wra   ,
           dac_sleep  
);

input             clk       ;
input             rst_n     ;
input             rx        ;
input             tx        ;
output            dac_mode  ;
output            dac_clka  ;
output [ 8-1:0]   dac_da    ;
output            dac_wra   ;
output            dac_sleep ;


wire   [15:0]     ctrl_dout     ;
wire   [ 7:0]     wave_dout     ;
wire              wave_dout_vld ;
wire              if_din_rdy    ;

`include "mdyCfg_wire.v"

wire  [63:0]          uart_dout      ;
wire                  uart_dout_vld  ;
wire  [63:0]          cfgCtrl_dout   ;
wire                  cfgCtrl_dout_vld  ;


top_uart_cfg u_top_uart_cfg(
    .clk      (clk           )   ,
    .rst_n    (rst_n         )   ,
    .cfg_head (16'h55d5      )   ,
    .rx       (rx            )   ,
    .tx       (tx            )   ,
    .din      (cfgCtrl_dout  )   ,
    .din_vld  (cfgCtrl_dout_vld)   ,
    .din_rdy  (              )   ,
    .dout     (uart_dout     )   ,
    .dout_vld (uart_dout_vld )    

);

mdyCfgCtrl u_mdyCfgCtrl(
    `include "mdyCfg_inst.v"
    .clk         (clk                ) ,
    .rst_n       (rst_n              ) ,
    .din         (uart_dout          ) ,
    .din_vld     (uart_dout_vld      ) ,
    .dout        (cfgCtrl_dout       ) ,
    .dout_vld    (cfgCtrl_dout_vld   )   

);

dds_ctrl u_dds_ctrl(
    .clk         (clk       ),
    .rst_n       (rst_n     ),
    .cfg_en      (CTRL0_en  ),
    .cfg_time    (TIME_data ),
    .cfg_repeat0 (REPEAT0_d0),
    .cfg_repeat1 (REPEAT0_d1),
    .cfg_repeat2 (REPEAT1_d2),
    .cfg_add0    (ADD0_d0   ),
    .cfg_add1    (ADD0_d1   ),
    .cfg_add2    (ADD1_d2   ),
    .dout        (ctrl_dout ) 
);

dds_wave u_dds_wave(
    .clk       (clk            ),
    .rst_n     (rst_n          ),
    .din_add   (ctrl_dout      ),
    .din_vld   (1              ),
    .cfg_mode  (CTRL0_mode     ),
    .dout      (wave_dout      ),
    .dout_vld  (wave_dout_vld  ),
    .dout_rdy  (if_din_rdy     ) 
    );


mdyAd9709If u_mdyAd9709If(
    .clk      (clk            ),
    .rst_n    (rst_n          ),
    .din      (wave_dout      ),
    .din_vld  (wave_dout_vld  ),
    .din_rdy  (if_din_rdy     ),
    .dac_mode (dac_mode       ),
    .dac_clka (dac_clka       ),
    .dac_da   (dac_da         ),
    .dac_wra  (dac_wra        ),
    .dac_sleep(dac_sleep      )
);



endmodule




