module top_uart_cfg(
    clk         ,
    rst_n       ,
    cfg_head    ,
    rx          ,
    tx          ,
    din         ,
    din_vld     ,
    din_rdy     ,
    dout        ,
    dout_vld     

);

parameter        D_W = 64    ;

parameter        BPS = 5208  ;
input            clk         ;
input            rst_n       ;
input  [15:0]    cfg_head    ;
input            rx          ;
output           tx          ;
input  [D_W-1:0] din         ;
input            din_vld     ;
output           din_rdy     ;

output [D_W-1:0] dout         ;
output           dout_vld     ;

wire   [ 7:0]    uart_in      ;
wire             uart_in_vld  ;
wire    [7:0]    uart_out     ;
wire             uart_out_vld ;

wire    [7:0]    p2s_dout     ;
wire             p2s_dout_vld ;
wire             tx_din_rdy   ;

uart_rx#(.BPS(BPS)) u_uart_rx(
    .clk      (clk         ),
    .rst_n    (rst_n       ),
    .din      (rx          ),
    .dout     (uart_in     ),
    .dout_vld (uart_in_vld ) 
);

uart_cfg_s2p  u_uart_cfg_s2p(
    .clk      (clk          ),
    .rst_n    (rst_n        ),
    .cfg_head (cfg_head     ),
    .din      (uart_in      ),
    .din_vld  (uart_in_vld  ),
    .dout     (dout         ),
    .dout_vld (dout_vld     ) 
);



uart_cfg_p2s#(.DIN_W(D_W),.DOU_W(8)) u_uart_cfg_p2s(
    .clk      (clk             ),
    .rst_n    (rst_n           ),
    .din      (din             ),
    .din_vld  (din_vld         ),
    .din_rdy  (din_rdy         ),
    .dout     (p2s_dout        ),
    .dout_vld (p2s_dout_vld    ),
    .dout_rdy (tx_din_rdy      ) 
);


uart_tx#(.BPS(BPS)) u_uart_tx(
    .clk     (clk            ),
    .rst_n   (rst_n          ),
    .din     (p2s_dout       ),
    .din_vld (p2s_dout_vld   ),
    .rdy     (tx_din_rdy     ),
    .dout    (tx             )  
);

endmodule
