module uart_cfg_p2s(
       clk      ,
       rst_n    ,
       din      ,
       din_vld  ,
       din_rdy  ,
       dout     ,
       dout_vld ,
       dout_rdy  
);

parameter             DIN_W  = 128     ;
parameter             DOU_W  =   8     ;

parameter             C_NUM  = DIN_W/DOU_W;

input                 clk            ;		
input                 rst_n          ;	
input [DIN_W-1:0]     din            ;
input                 din_vld        ;
output                din_rdy        ;
output[DOU_W-1:0]     dout           ;		
output                dout_vld       ;
input                 dout_rdy       ;

reg                   din_rdy        ;
wire                  flag_add_start ;
reg                   flag_add       ;
reg [DIN_W-1:0]       din_ff         ;
reg [ 7:0]            cnt0           ;
wire                  add_cnt0       ;
wire                  end_cnt0       ;
reg  [DOU_W-1:0]      dout           ;		
reg                   dout_vld       ;

assign flag_add_start = flag_add==0 && din_vld ;
always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        flag_add <= 0;
    end
    else if(flag_add_start)begin
        flag_add <= 1;
    end
    else if(end_cnt0)begin
        flag_add <= 0;
    end
end

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        din_ff  <= 0;
    end
    else if(flag_add_start) begin
        din_ff  <= din;
    end
end


always @(posedge clk or negedge rst_n) begin 
    if (rst_n==0) begin
        cnt0 <= 0; 
    end
    else if(add_cnt0) begin
        if(end_cnt0)
            cnt0 <= 0; 
        else
            cnt0 <= cnt0+1 ;
   end
end
assign add_cnt0 = flag_add && dout_rdy        ;
assign end_cnt0 = add_cnt0  && cnt0 ==C_NUM-1 ;

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        dout <= 0;
    end
    else if(add_cnt0) begin
        dout <= din_ff [DIN_W-cnt0*DOU_W-1 -:DOU_W] ;
    end
end

always  @(posedge clk or negedge rst_n)begin
    if(rst_n==1'b0)begin
        dout_vld <= 0;
    end
    else begin
        dout_vld <= add_cnt0 ;
    end
end

always  @(*)begin
    if(flag_add || din_vld)
        din_rdy = 0;
    else
        din_rdy = 1;
end

endmodule

